[TOC]


# Connectors


## OpenSesame

OpenSesame is a graphical experiment builder for the social sciences. Sigmund works as a co-pilot inside the OpenSesame interface. For more information and installation instructions, visit:

- <https://osdoc.cogsci.nl/tutorials/beginner-sigmund/>


## Sigmund Analyst (code editor)

Sigmund Analyst is a code editor focused on Python data analysis. Sigmund works as a co-pilot inside Sigmund Analyst. For more information and installation instructions, visit:

- <https://github.com/open-cogsci/sigmund-analyst>


## JupyterLab, IPython, Notebook, Spyder

Jupyterlab (IPython) is the technology behind Notebook and also powers the Python console in Spyder and several other code editors. Sigmund can control your Jupyterlab (IPython) kernel. For more information and installation instructions, visit:

- <https://github.com/open-cogsci/jupyter-extension-sigmund>
